.. _api_geometry_ellipsoid:

.. currentmodule:: microstructpy.geometry

microstructpy.geometry.Ellipsoid
================================

.. autoclass:: Ellipsoid
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance: